# Solana Toolbox Library

## Overview

**Solana Toolbox** is a Python library designed to make working with the [Solana blockchain](https://solana.com) simple and efficient. It provides developers with essential tools and utilities.

---

## Features

- 🔗 **Jupiter Swap**: Minimal Jupiter sdk.  

---

## Installation

Install the library using pip:

```bash
pip install solana-toolbox
```

---

## Quick Start

### 1. Jupiter Api

```python
import asyncio
from solana_toolbox import JupiterApi

TOKENS = ["EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v", "So11111111111111111111111111111111111111112"]
result = asyncio.run(
    JupiterApi.get_token_price(*TOKENS)
)
```
---

<!-- ## Documentation

Detailed documentation is available [here](https://your-documentation-link.com).
 -->
<!-- ### Core Modules

| Module                  | Description                                       |
|--------------------------|---------------------------------------------------|
| `jup`                   | Access the jupiter minimal sdk.                   |

--- -->

<!-- ## Examples

Check out the [examples](https://github.com/yourusername/solana-toolbox/tree/main/examples) directory for real-world use cases:

1. **Checking the price of a mint in USD**

---

## Contributing

We welcome contributions! Please check our [CONTRIBUTING.md](https://github.com/yourusername/solana-toolbox/blob/main/CONTRIBUTING.md) for guidelines on how to get involved.

---

## Roadmap

- [ ] Add minimal support for jupiter.
- [ ] Add minimal support pumpfun.  
- [ ] Add minimal support for raydium.  

---
 -->
## License

This library is distributed under the [MIT License](https://opensource.org/licenses/MIT).

---

## Acknowledgments

Special thanks to the Python and Solana communities for their continued support and contributions.

---

Let me know if you need any specific examples or sections expanded!